<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/pypi/pyversions/ini2dict.svg?longCache=True)](https://pypi.org/project/ini2dict/)

#### Installation
```bash
$ [sudo] pip install ini2dict
```

#### Functions
function|`__doc__`
-|-
`ini2dict.read(path)` |return a dictionary with ini file data

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>